#
# spec file for package postgresql-init
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Url:            http://www.postgresql.org/
Summary:        Init script and other infrastructure for PostgreSQL
License:        PostgreSQL
Group:          Productivity/Databases/Servers

Name:           postgresql-init
Version:        9.4
Release:        14.5
Source0:        postgresql-init
Source1:        postgresql-sysconfig
Source2:        postgresql-firewall
Source3:        postgresql-tmpfiles.conf
Source4:        postgresql.service
BuildRequires:  pwdutils
%if 0%{?suse_version} >= 1210
BuildRequires:  systemd-rpm-macros
%endif
%{?systemd_requires}
Requires(pre):  pwdutils
Requires(post): %fillup_prereq
Requires(postun): %insserv_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%if 0%{?suse_version} > 1100
    %define fwdir /etc/sysconfig/SuSEfirewall2.d/services
    %define fwname postgresql
%else
    %define fwdir /etc/sysconfig/scripts
    %define fwname SuSEfirewall2-postgresql
%endif

%description
This package contains the systemd service file, sysconfig template and
firewall service file for the PostgreSQL server. It was separated from
the postgresql*-server binary package to allow parallel installation
of several server versions.

%prep

%build

%install
install -m755 -d %buildroot/usr/lib
install -m755 %{S:0} %buildroot/usr/lib

install -m755 -d %buildroot/var/adm/fillup-templates
install -m644 %{S:1} %buildroot/var/adm/fillup-templates/sysconfig.postgresql

install -m755 -d %buildroot%fwdir
install -m644 %{S:2} %buildroot%fwdir/%fwname

install -m755 -d %buildroot/%_tmpfilesdir
install -m644 %{S:3} %buildroot%_tmpfilesdir/postgresql.conf

install -m755 -d %buildroot%_unitdir
install -m444 %{S:4} %buildroot%_unitdir

install -m755 -d %buildroot/usr/sbin
ln -sf %_sbindir/service %buildroot%_sbindir/rcpostgresql

%pre
%service_add_pre postgresql.service
groupadd -g 26 -o -r postgres >/dev/null 2>/dev/null || :
useradd -g postgres -o -r -d /var/lib/pgsql -s /bin/bash \
	-c "PostgreSQL Server" -u 26 postgres 2>/dev/null || :

%post
%fillup_only -n postgresql
%tmpfiles_create %_tmpfilesdir/postgresql.conf
%service_add_post postgresql.service

%preun
%service_del_preun postgresql.service

%postun
%service_del_postun postgresql.service

%files
%defattr(-,root,root,-)
%_unitdir/*
/usr/lib/*
%dir %fwdir
%config %fwdir/%fwname
/var/adm/fillup-templates/sysconfig.postgresql
/usr/sbin/rcpostgresql
%_tmpfilesdir/postgresql.conf

%changelog
* Thu Jun  9 2016 max@suse.com
- Migrate to systemd (bsc#906900):
  * Strip down the init script to the minimum that is needed for
    being called from systemd.
  * Add a unit file to call the former init script.
  * Drop $DATADIR/postmaster.log and log to syslog instead.
* Mon Feb 15 2016 max@suse.com
- Increase the default timeout for pg_ctl from 60 to 600 seconds
  and make it configurable (bsc#966285).
* Tue Feb  2 2016 max@suse.com
- Change the permissions and ownership of /var/run/postgresql to
  match those of /tmp (the traditional location of PostgreSQL's
  unix domain sockets and lock files), so that users other than
  "postgres" are able to start teir own database instances.
* Mon Oct 12 2015 max@suse.com
- Move systemd related stuff and user/group creation from
  postgresqlXX-server to postgresql-init (bsc#950486).
* Thu Feb 12 2015 mrueckert@suse.de
- do not own directories which are already owned by the filesystem
  package
* Thu Feb 12 2015 mrueckert@suse.de
- bump version so it can bue used with 9.4
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Thu Jul 31 2014 meissner@suse.com
- no need to directly require SuSEfirewall2 for the service,
  just also own the directory. (avoid massive rebuilds for SUSEfirewall2
  changes).
* Wed Sep 11 2013 max@suse.com
- Bump version number to 9.3 to be dependency compatible with the
  latest PostgreSQL version.
* Wed Jul 17 2013 max@suse.com
- "ident sameuser" was already gone in 8.4.
* Fri Oct  5 2012 max@suse.com
- Fix path and naming of fierewall script for SLE10.
* Thu Oct  4 2012 max@suse.com
- Bump version to 9.2 to be in sync with the postgresql package.
* Fri Sep 28 2012 max@suse.com
- Run systemctl daemon_reload in %%post and %%postun
* Wed Sep 26 2012 max@suse.com
- Write postmaster output to a log file, so that processes starting
  PostgreSQL in a pipe don't hang (bnc#779927, bnc#780978).
* Wed Aug 29 2012 max@suse.com
- Don't remove stale PID files and local sockets. PostgreSQL does
  not need it anymore, and the way it was done sometimes caused
  false removals (bnc#777797).
* Fri Aug 10 2012 max@suse.com
- Let the init script always use the private dir for existing
  databases, so that it doesn't fail when the active version
  has no server package installed (bnc#775402).
- Make the init script more verbose when things go wrong because
  of missing or non-matching server binaries.
- Let pg_ctl and the server process write to stdout again, so
  that it is easier to find out what happened if start failed.
- Make sure the init package doesn't get installed together with
  an old server package (bnc#775399).
- Add %%stop_on_removal in case the init script gets uninstalled
  before the server as RPM dependencies don't seem to be enough to
  ensure this.
* Tue Aug  7 2012 max@suse.com
- Don't install the firewall script in place of the sysconfig
  template.
* Mon Aug  6 2012 max@suse.com
- Package the sysconfig template under the right name, so that
  %%fillup_only picks it up (bnc#774616).
- Redirect early postmaster output to a logfile, so that it
  doesn't cause logger to hang on startup (bnc#774617).
- Correct dependencies on insserv and fillup.
* Wed Aug  1 2012 max@suse.com
- Update try-restart from /etc/init.d/skeleton
- Clarify output when using a different version than the active
  alternative.
- Remove the silent flag from pg_ctl for start/stop and let it log
  to syslog.
* Wed Jul 18 2012 max@suse.com
- Initial packaging of init script, fillup template and firewall
  service file into a separate package.
